@@ -18,11 +18,11 @@
  *
  * Created 17.6.99 by Hendrik
  *
- * Time-stamp: <Wednesday 22 May 02 14:10:38 tews@ithif51>
+ * Time-stamp: <Wednesday 18 September 02 17:26:13 tews@ithif51>
  *
  * the adt theories
  *
- * $Id: adt_theory.ml,v 1.15 2002/07/18 13:43:20 tews Exp $
+ * $Id: adt_theory.ml,v 1.17 2002/10/28 16:33:17 tews Exp $
  *
  *)
 
@@ -78,6 +78,7 @@ class ccsl_isar_start_adt adt =
       IsabelleStartFile
       (ccsl_adt_file_name adt)
       imports
+      true				(* do proofs *)
 
 
 class ccsl_isar_close_adt adt =
@@ -88,6 +89,7 @@ class ccsl_isar_close_adt adt =
     IsabelleCloseFile
     (ccsl_adt_file_name adt)
     []
+    true				(* do proofs *)
 
     
 
@@ -1338,6 +1340,7 @@ class ['class_type, 'member_type] ccsl_pre_adt_map_theory
 	     let to_args = ccsl_substitute_arguments to_subst args
 	     in
 	     let rec do_v th_name accu = function
+	       | Unused
 	       | Pos -> (th_name, from_args @ to_args) :: accu
 	       | Neg -> (th_name, to_args @ from_args) :: accu
 	       | Mixed -> do_v th_name (do_v th_name accu Pos) Neg
