@@ -18,17 +18,23 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Monday 8 October 01 17:58:00 tews@ithif51>
+ * Time-stamp: <Friday 5 July 02 18:29:50 tews@ithif51>
  *
  * adt theories
  *
- * $Id: adt_theory.mli,v 1.4 2002/05/03 15:01:05 tews Exp $
+ * $Id: adt_theory.mli,v 1.5 2002/07/18 13:43:20 tews Exp $
  *
  *)
 
 
 open Classtypes
 
+class ccsl_isar_start_adt
+  : ccsl_iface_type -> ccsl_sig_theory_type
+
+class ccsl_isar_close_adt
+  : ccsl_iface_type -> ccsl_sig_theory_type
+
 class ccsl_pvs_adt_theory 
   : ccsl_iface_type ->  ccsl_adt_theory_type 
   
