@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Thursday 4 July 02 18:46:40 tews@ithif51>
+ * Time-stamp: <Monday 28 October 02 14:40:15 tews@ithif51>
  *
  * Bisimilarity theories
  *
- * $Id: bisim_theory.ml,v 1.13 2002/07/18 13:43:20 tews Exp $
+ * $Id: bisim_theory.ml,v 1.14 2002/10/28 16:33:17 tews Exp $
  *
  *)
 
@@ -103,10 +103,6 @@ class ['class_type, 'member_type] ccsl_pre_bibisim_theory
 	       else do_nonconst_anc anc args
 					(* no other stuff *)
 	   | Unresolved_renaming _
-(* NO JAVA ANCESTORS
- * 	      | Resolved_ancestor _ 
- * 	      | Unresolved_ancestor _ 
- *)
 	     -> assert(false)
 	)
 	cl#get_ancestors in
@@ -168,7 +164,7 @@ class ['class_type, 'member_type] ccsl_pre_bibisim_theory
 		    | Resolved_renaming(oanc, args,_,ianc,_) -> oanc,args
 					(* no other stuff here *)
 		    | Unresolved_renaming _
-		    | _ -> assert(false)
+			-> assert(false)
 		 ) cl#get_ancestors
       in
       let self_type_arguments = [self#self1_argument; self#self2_argument] in
