@@ -18,17 +18,23 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Monday 8 October 01 17:58:00 tews@ithif51>
+ * Time-stamp: <Tuesday 16 July 02 22:24:21 tews@ithif56.inf.tu-dresden.de>
  *
  * theory for theorems
  *
- * $Id: class_theorems_theory.mli,v 1.2 2002/05/03 15:01:07 tews Exp $
+ * $Id: class_theorems_theory.mli,v 1.3 2002/07/18 13:43:21 tews Exp $
  *
  *)
 
 
 open Classtypes
 
+class ccsl_isar_start_theorems
+  : ccsl_iface_type -> ccsl_sig_theory_type
+
+class ccsl_isar_close_theorems
+  : ccsl_iface_type -> ccsl_sig_theory_type
+
 class ccsl_class_theorem_theory
   : ccsl_iface_type ->  ccsl_class_theory_type 
 
