@@ -18,22 +18,26 @@
  *
  * Created 11.10.01 by Hendrik
  *
- * Time-stamp: <Monday 8 October 01 17:58:00 tews@ithif51>
+ * Time-stamp: <Friday 5 July 02 18:05:14 tews@ithif51>
  *
- *  empty type
+ * addon theories for isabelle and pvs
  *
- * $Id: emptytype_theory.mli,v 1.3 2002/05/03 15:01:08 tews Exp $
+ * $Id: emptytype_theory.mli,v 1.4 2002/07/18 13:43:21 tews Exp $
  *
  *)
 
 
 open Classtypes
 
-class ccsl_empty_type_theory : ccsl_class_theory_type 
+class ccsl_empty_type_theory : ccsl_sig_theory_type 
 					       
-class ccsl_empty_fun_theory : ccsl_class_theory_type 
+class ccsl_empty_fun_theory : ccsl_sig_theory_type 
 					       
+class ccsl_isabelle_addon_theory : ccsl_sig_theory_type
 
+class ccsl_isar_start_prelude : ccsl_sig_theory_type
+
+class ccsl_isar_close_prelude : ccsl_sig_theory_type
 
 (*** Local Variables: ***)
 (*** version-control: t ***)
