@@ -18,13 +18,13 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Wednesday 15 May 02 17:08:10 tews@ithif51>
+ * Time-stamp: <Monday 28 October 02 16:26:45 tews@ithif51>
  *
  * Feature pass for CCSL
  * Determines the features for adt's, classes and 
  * groundsignature 
  *
- * $Id: feature.ml,v 1.5 2002/05/22 13:42:39 tews Exp $
+ * $Id: feature.ml,v 1.6 2002/10/28 16:33:18 tews Exp $
  *
  *)
 
@@ -362,6 +362,9 @@ let do_adt adt =
 	);
       
       if adt#has_feature CarrierClassComponentFeature then
+(* HENDRIK: PVS type abbreviations work
+ -> need to distinguish between ground types and class types
+*)
 	feature_error loc
 	  ("Adt " ^ adt#get_name ^ 
 	   " instanciates a class or a ground type with Carrier.\n" ^
