@@ -18,11 +18,11 @@
  *
  * Created 11.10.01 by Hendrik
  *
- * Time-stamp: <Tuesday 16 July 02 10:09:03 tews@ithif51>
+ * Time-stamp: <Monday 28 October 02 14:52:55 tews@ithif51>
  *
  * full invariants and bisimulations
  *
- * $Id: full_liftings_theory.ml,v 1.8 2002/07/18 13:43:21 tews Exp $
+ * $Id: full_liftings_theory.ml,v 1.9 2002/10/28 16:33:18 tews Exp $
  *
  *)
 
@@ -151,7 +151,7 @@ class ['class_type, 'member_type] ccsl_pre_full_invariant_theory
                     | Resolved_renaming(oanc,args,_,ianc,_) -> oanc,args
                                         (* no other stuff here *)
                     | Unresolved_renaming _
-                    | _ -> assert(false)
+                      -> assert(false)
                  ) cl#get_ancestors
       in
 						(* lifting for one ancestor *)
@@ -625,7 +625,7 @@ class ['class_type, 'member_type] ccsl_pre_full_bibisim_theory
                     | Resolved_renaming(oanc,args,_,ianc,_) -> oanc,args
                                         (* no other stuff here *)
                     | Unresolved_renaming _
-                    | _ -> assert(false)
+                      -> assert(false)
                  ) cl#get_ancestors
       in
       let do_ancestor (anc, anc_arguments) =
