@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Wednesday 17 July 02 17:28:48 tews@ithif51>
+ * Time-stamp: <Monday 28 October 02 14:43:20 tews@ithif51>
  *
  * the class for ccsl adt's and classes
  *
- * $Id: iface_class.ml,v 1.17 2002/07/18 13:43:21 tews Exp $
+ * $Id: iface_class.ml,v 1.18 2002/10/28 16:33:18 tews Exp $
  *
  *)
 
@@ -229,6 +229,11 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
        * see iter_component_arg and iter_components
        *)
     method add_component (v,c,inpargs) =
+(*					(* debugging support *)
+      let cname = c#get_name in
+      let sname = self#get_name in
+					(* debugging support *)
+*)
       let rec do_it args = function
 	| ((v',c',args') as comp') :: l ->
 	    if (c'#get_name = c#get_name) &&
