@@ -18,11 +18,11 @@
  *
  * Created 17.6.99 by Hendrik
  *
- * Time-stamp: <Monday 15 July 02 16:21:33 tews@ithif51>
+ * Time-stamp: <Wednesday 24 July 02 16:30:23 tews@ithif51>
  *
  * the ccsl interface theory
  *
- * $Id: interface_theory.ml,v 1.13 2002/07/18 13:43:22 tews Exp $
+ * $Id: interface_theory.ml,v 1.14 2002/09/18 15:35:03 tews Exp $
  *
  *)
 
@@ -85,6 +85,7 @@ class ccsl_isar_start_class cl =
       IsabelleStartFile
       (ccsl_class_file_name cl)
       imports
+      true				(* do proofs *)
 
 
 class ccsl_isar_close_class cl =
@@ -95,6 +96,7 @@ class ccsl_isar_close_class cl =
     IsabelleCloseFile
     (ccsl_class_file_name cl)
     []
+    true				(* do proofs *)
 
     
 
