@@ -18,11 +18,11 @@
  *
  * Created 17.6.99 by Hendrik
  *
- * Time-stamp: <Wednesday 15 May 02 18:42:48 tews@ithif51>
+ * Time-stamp: <Thursday 4 July 02 18:29:39 tews@ithif51>
  *
  * Lifttings and invariants
  *
- * $Id: invariance_theory.ml,v 1.7 2002/05/22 13:42:40 tews Exp $
+ * $Id: invariance_theory.ml,v 1.8 2002/07/18 13:43:22 tews Exp $
  *
  *)
 
@@ -212,7 +212,9 @@ class ['class_type, 'member_type] ccsl_pre_lift_theory
       self#invariance (name_of_public_invariance cl) 
 	(name_of_public_class_pred cl)
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 
     method make_body = 
       [	Import([ccsl_interface_theory_name cl, self#simple_arguments]);
@@ -286,7 +288,9 @@ class virtual ['class_type, 'member_type] ccsl_pre_invariance_rewrite_theory
 
     initializer top_theory#override_file_name (ccsl_class_file_name cl)
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 
 	(* this gets overriden in derived classes to specialize
 	 * this class for full or public invariance 
@@ -403,7 +407,8 @@ class virtual ['class_type, 'member_type] ccsl_pre_invariance_rewrite_theory
       let anc_inv_th_list = 
 	(ccsl_lift_theory_name cl) :: (collect_anc_names cl)
       in
-      	Anon_proof( make_simple_proof(
+	PvsProof(
+      	  Anon_proof( make_simple_proof(
 		      [ skosimp_star;
 		      	expand self#invariant_pred_string;
 		      	inst_num (-1);
@@ -412,11 +417,12 @@ class virtual ['class_type, 'member_type] ccsl_pre_invariance_rewrite_theory
 		      	pvs_assert;
 		      	flatten;
 		      	repeat (rewrite_left m#get_name);
-		      	super_inst]))
+		      	super_inst])))
 
     method private inv_constructor_proof =
       let inv_th = (ccsl_lift_theory_name cl) in
-      	Anon_proof( make_simple_proof(
+	PvsProof(
+      	  Anon_proof( make_simple_proof(
 		      [ skosimp_star;
 			expand (name_of_initially cl);
 		      	inst_num (-1);
@@ -424,7 +430,7 @@ class virtual ['class_type, 'member_type] ccsl_pre_invariance_rewrite_theory
 		      	auto_rewrite_theories [inv_th];
 		      	pvs_assert;
 		      	flatten;
-		      	super_inst]))
+		      	super_inst])))
 
     (***************************************************
      *
