@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Sunday 19 May 02 13:34:40 tews@ithif56.inf.tu-dresden.de>
+ * Time-stamp: <Monday 28 October 02 16:36:05 tews@ithif51>
  *
  * predicate and relation lifting
  *
- * $Id: lifting.ml,v 1.19 2002/05/22 13:42:40 tews Exp $
+ * $Id: lifting.ml,v 1.20 2002/10/28 16:33:18 tews Exp $
  *
  *)
 
@@ -1161,7 +1161,9 @@ and pre_inline_adt_rel_lifting eq_types self1_subst self2_subst
   param_rel_lifting self_lifting top_name_space variance adt args 
   expr1 expr2
   = 
-  if constant_arg_list (fun id -> List.mem_assoc id param_rel_lifting) args
+  if 
+    (constant_arg_list (fun id -> List.mem_assoc id param_rel_lifting) args)
+    && (not (class_ingredient_args args))
   then 
     Expression(Equal(expr1, expr2))
   else
