@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Monday 8 October 01 17:58:00 tews@ithif51>
+ * Time-stamp: <Thursday 16 May 02 17:16:01 tews@ithif51>
  *
  * predicate and relation lifting
  *
- * $Id: lifting.mli,v 1.6 2002/01/23 16:00:16 tews Exp $
+ * $Id: lifting.mli,v 1.8 2002/05/22 13:42:41 tews Exp $
  *
  *)
 
@@ -59,7 +59,7 @@ constraint 'mem = <get_domain : ('cl,'mem) top_pre_types;
 		   get_name : string;
 		   get_accessors : 'mem list;
 		   get_recognizer : 'mem;
-		   get_sort : 'mem top_member_sort;
+		   get_sort : 'mem top_pre_member_sort;
 		   ..>
 
 (***********************************************************************
@@ -84,7 +84,7 @@ constraint 'mem = <get_domain : ('cl,'mem) top_pre_types;
 		   get_name : string;
 		   get_accessors : 'mem list;
 		   get_recognizer : 'mem;
-		   get_sort : 'mem top_member_sort;
+		   get_sort : 'mem top_pre_member_sort;
 		   ..>
 
 (***********************************************************************
@@ -538,5 +538,6 @@ val transition_cases_for_method:
 (*** version-control: t ***)
 (*** kept-new-versions: 5 ***)
 (*** delete-old-versions: t ***)
+(*** time-stamp-line-limit: 30 ***)
 (*** End: ***)
 
