@@ -18,11 +18,11 @@
  *
  * Created 17.6.99 by Jan
  *
- * Time-stamp: <Wednesday 22 May 02 18:23:12 tews@ithif51>
+ * Time-stamp: <Tuesday 16 July 02 10:15:44 tews@ithif51>
  *
  * Liftings and invariants
  *
- * $Id: methodinv_theory.ml,v 1.12 2002/05/30 13:10:30 tews Exp $
+ * $Id: methodinv_theory.ml,v 1.13 2002/07/18 13:43:22 tews Exp $
  *
  *)
 
@@ -71,7 +71,9 @@ class ['class_type, 'member_type] ccsl_pre_method_idtype_adt
 
     method get_parameters = []
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 
     initializer top_theory#override_file_name (ccsl_class_file_name cl)
 
@@ -81,7 +83,7 @@ class ['class_type, 'member_type] ccsl_pre_method_idtype_adt
       let methods = self#get_lifting_methods
       in
         if (List.length methods) > 0 then
-	  Datatypedecl("", [],
+	  Datatypedecl(self#get_name, [],
 		       List.map
 			 (fun m -> (name_of_method_tag m, [], 
 				    name_of_method_tag_recognizer m)
@@ -89,7 +91,7 @@ class ['class_type, 'member_type] ccsl_pre_method_idtype_adt
 			 methods
 		      )
         else
-	  Datatypedecl("", [],
+	  Datatypedecl(self#get_name, [],
 		       [("no_method", [], "no_method?")]
 		      )
 
@@ -390,7 +392,9 @@ class ['class_type, 'member_type] ccsl_pre_method_lift_theory
 		     )))))
        
                           
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 
     method make_body =
       [ Import(
@@ -481,7 +485,9 @@ class ['class_type, 'member_type] ccsl_pre_method_invariance_rewrite_theory
                                
      initializer top_theory#override_file_name (ccsl_class_file_name cl)
        
-     method get_proofs = []
+(* ISAR
+ * 	method get_proofs = []
+ *)
                            
      (* this gets overriden in derived classes to specialize
       * this class for private or public invariance
@@ -499,7 +505,7 @@ class ['class_type, 'member_type] ccsl_pre_method_invariance_rewrite_theory
 	| Some ms -> ms
 	| None -> 
 	    let methods = 
-	      List.filter (fun m -> m#needs_lifting && m#is_action) 
+	      List.filter (fun m -> m#is_action && m#needs_lifting) 
 		cl#get_all_members
 	    in
 	      rewrite_methods <- Some methods;
@@ -631,9 +637,10 @@ class ['class_type, 'member_type] ccsl_pre_method_invariance_rewrite_theory
                ) 
              )) 
            ),
-	   Anon_proof( make_simple_proof(
+	   PvsProof(
+	     Anon_proof( make_simple_proof(
 			 [ grind ])
-		     )
+		     ))
 	 )   
 	  
      (*   
@@ -870,14 +877,16 @@ class ['class_type, 'member_type] ccsl_pre_method_invariance_inherit_theory
        
      method get_name = ccsl_method_invariance_inherit_name cl
 			 
-     method get_proofs = []
+(* ISAR
+ * 	method get_proofs = []
+ *)
                            
      (* this gets overriden in derived classes to specialize
       * this class for private or public invariance
       *)
                            
-     method private invariant_pred =
-       Expression(ConstantPredicate(name_of_method_invariance cl))
+     method private invariant_pred use_this_cl =
+       Expression(ConstantPredicate(name_of_method_invariance use_this_cl))
          
 
 (* Apparently not needed
@@ -906,7 +915,7 @@ class ['class_type, 'member_type] ccsl_pre_method_invariance_inherit_theory
      method private this_class_pred l_term p_term = 
        Application(
 	 Application(
-	   Application(self#invariant_pred, coalgebra_term),
+	   Application(self#invariant_pred cl, coalgebra_term),
 	   l_term),
 	 p_term)       
 
@@ -914,7 +923,7 @@ class ['class_type, 'member_type] ccsl_pre_method_invariance_inherit_theory
        Application(
 	 Application(
 	   Application(
-	     self#invariant_pred, 
+	     self#invariant_pred acl, 
 	     Application(Term(super_access_method(acl),
 			      Always,[]), 
 			 coalgebra_term)),
@@ -938,8 +947,14 @@ class ['class_type, 'member_type] ccsl_pre_method_invariance_inherit_theory
 		amethods)
        in let alist =			(* anticipate change here *)
 	 List(List.map 
-		(fun m -> Term(name_of_method_tag_string m#last_name, 
-			       Always, []))
+		(fun m -> 
+		   if !output_mode = Isa_mode
+		   then
+		     QualifiedTerm(isar_theory_name acl, Always, [], 
+				   name_of_method_tag_string m#last_name)
+		   else
+		     Term(name_of_method_tag_string m#last_name, Always, [])
+		)
 		amethods)
        in
 	 Lemma(
@@ -964,7 +979,7 @@ class ['class_type, 'member_type] ccsl_pre_method_invariance_inherit_theory
 	 ]
        else
 	 let amethods = 
-	   List.filter (fun m -> m#needs_lifting && m#is_method) 
+	   List.filter (fun m -> m#is_method && m#needs_lifting ) 
 	     acl#get_all_members
 	 in
 	   if amethods = [] 
@@ -1298,8 +1313,8 @@ class  ['class_type, 'member_type] ccsl_pre_box_theory
 	  name_of_method_id;
 	  name_of_greatest_invariance cl;
 	  name_of_h_gi;
-	  name_of_box;
-	  name_of_diamond;
+	  name_of_box cl;
+	  name_of_diamond cl;
 	]
        )
 
@@ -1307,7 +1322,7 @@ class  ['class_type, 'member_type] ccsl_pre_box_theory
  * 	initializer name_of_list <- create_one_id ns self#list_type
  *)
 
-     method private diamond_term = Term(name_of_diamond, Always, []) 
+     method private diamond_term = Term(name_of_diamond cl, Always, []) 
 
      val p_pred = Expression(ConstantPredicate("P")) 
      val q_pred = Expression(ConstantPredicate("Q")) 
@@ -1318,7 +1333,7 @@ class  ['class_type, 'member_type] ccsl_pre_box_theory
        Application(
 	 Application(
 	   Application(
-	     Term(name_of_box, Always, []),
+	     Term(name_of_box cl, Always, []),
 	     coalgebra_term
 	   ),
 	   s
@@ -1330,7 +1345,7 @@ class  ['class_type, 'member_type] ccsl_pre_box_theory
        Application(
 	 Application(
 	   Application(
-	     Term(name_of_diamond, Always, []),
+	     Term(name_of_diamond cl, Always, []),
 	     coalgebra_term
 	   ),
 	   s
@@ -1355,7 +1370,7 @@ class  ['class_type, 'member_type] ccsl_pre_box_theory
        let y = create_one_id sub_ns Self in
        let y_term = Term(y, Always, []) in
 	 Defn(
-	   name_of_box,
+	   name_of_box cl,
 	   [[Declared(name_of_coalgebra, self#coalgebra_type)];
 	    [Undeclared(l, self#list_type)];
 	    [Declared("P",pred_type)]],
@@ -1407,7 +1422,7 @@ class  ['class_type, 'member_type] ccsl_pre_box_theory
        let x : string = fst(List.nth vars 0) in
        let y : string = fst(List.nth vars 1) in
 	 Defn(
-	   name_of_diamond,
+	   name_of_diamond cl,
 	   [[Declared(name_of_coalgebra, self#coalgebra_type)];
 	    [Undeclared(l, self#list_type)];
 	    [Declared("P",pred_type)]],
@@ -1734,7 +1749,9 @@ class  ['class_type, 'member_type] ccsl_pre_box_theory
                                
      initializer top_theory#override_file_name (ccsl_class_file_name cl)
 
-     method get_proofs = []
+(* ISAR
+ * 	method get_proofs = []
+ *)
 			 
      method make_body =
        [ 
@@ -1827,7 +1844,7 @@ class ['class_type, 'member_type] ccsl_pre_box_inherit_theory
 	 Application(
 	   Application(
 	     Application(
-	       Term(name_of_box,Always,[]), 
+	       Term(name_of_box cl,Always,[]), 
 	       coalgebra_term),
 	     l_term),
 	   p_term),
@@ -1838,7 +1855,7 @@ class ['class_type, 'member_type] ccsl_pre_box_inherit_theory
 	 Application(
 	   Application(
 	     Application(
-	       Term(name_of_box,Always,[]),
+	       Term(name_of_box acl,Always,[]),
 	       Application(Term(super_access_method(acl),
 				Always,[]), 
 			   coalgebra_term)),
@@ -1918,7 +1935,9 @@ object (self : 'self)
       step_constructor_declarations ns cl;
     ]
   
-  method get_proofs = []
+(* ISAR
+ *   method get_proofs = []
+ *)
 
 end (* ccsl_pre_step_adt *)
 
@@ -1959,8 +1978,8 @@ class ['class_type, 'member_type] ccsl_pre_path_theory
 	  name_of_coalgebra;
 	  "P";
 	  name_of_method_id;
-	  name_of_box;
-	  name_of_diamond;
+	  name_of_box cl;
+	  name_of_diamond cl;
 	]
        )
 
@@ -1985,7 +2004,7 @@ class ['class_type, 'member_type] ccsl_pre_path_theory
 
      method private trans_term = Term(name_of_transition,Never,[])
 
-     method private diamond_term = Term(name_of_diamond, Always, []) 
+     method private diamond_term = Term(name_of_diamond cl, Always, []) 
 
      val q_pred = Expression(ConstantPredicate("Q")) 
      val pred_type = Function(Self, Bool)
@@ -1994,7 +2013,7 @@ class ['class_type, 'member_type] ccsl_pre_path_theory
        Application(
 	 Application(
 	   Application(
-	     Term(name_of_box, Always, []),
+	     Term(name_of_box cl, Always, []),
 	     coalgebra_term
 	   ),
 	   s
@@ -2492,7 +2511,9 @@ class ['class_type, 'member_type] ccsl_pre_path_theory
 		       
 			 
 	       
-     method get_proofs = []
+(* ISAR
+ * 	method get_proofs = []
+ *)
 			 
      method make_body =
        [	    
