@@ -18,11 +18,11 @@
  *
  * Created 16.03.00 by Jan
  *
- * Time-stamp: <Monday 15 July 02 17:04:34 tews@ithif51>
+ * Time-stamp: <Monday 28 October 02 14:44:56 tews@ithif51>
  *
  * Coalgebra morphism theories
  *
- * $Id: morphism_theory.ml,v 1.13 2002/07/18 13:43:23 tews Exp $
+ * $Id: morphism_theory.ml,v 1.14 2002/10/28 16:33:18 tews Exp $
  *
  *)
 
@@ -108,11 +108,12 @@ class ['class_type, 'member_type] ccsl_pre_morphism_theory
 		      right_domain_subst args comp#get_parameters)	
 	       in let res_pos_args = 
 		   (substitute_variance_argument_list
-		    codomain_pos_subst args comp#get_parameters)
+		      codomain_pos_subst args comp#get_parameters)
 	       in let res_neg_args = 
 		   (substitute_variance_argument_list
-		    codomain_neg_subst args comp#get_parameters)
+		      codomain_neg_subst args comp#get_parameters)
 	       in let rec do_v accu th_name = function
+		 | Unused
 		 | Pos -> ((th_name, left_args @ res_pos_args) :: 
 			     (th_name, right_args @ res_pos_args)
 			   :: accu)
@@ -131,6 +132,10 @@ class ['class_type, 'member_type] ccsl_pre_morphism_theory
 		     else
 		       accu
 		 | Spec_adt -> 
+(*					(* debugging support *)
+		     let compname = comp#get_name in
+					(* debugging support *)
+*)
 		     if comp#has_feature NeedsMapFeature
 		     then 
 		       do_v accu (ccsl_adt_map_theory_name comp) v
@@ -184,7 +189,7 @@ class ['class_type, 'member_type] ccsl_pre_morphism_theory
 
 					(* no other stuff here *)
 	     | Unresolved_renaming _
-	     | _ -> assert(false)
+	       -> assert(false)
 	  ) 
 	  cl#get_ancestors
 	  ([List.filter method_filter cl#get_actions], [])
@@ -1050,6 +1055,7 @@ class ['class_type, 'member_type] ccsl_pre_map_struct_theory
 	     in let to_args = substitute_arguments_types_only 
 				eq_types self#to_subst args
 	     in let rec do_v th_name accu = function
+	       | Unused
 	       | Pos -> (th_name, from_args @ to_args) :: accu
 	       | Neg -> (th_name, to_args @ from_args) :: accu
 	       | Mixed -> do_v th_name (do_v th_name accu Pos) Neg
