@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Tuesday 16 July 02 21:22:38 tews@ithif56.inf.tu-dresden.de>
+ * Time-stamp: <Monday 28 October 02 14:52:55 tews@ithif51>
  *
  * Typechecking with unification
  *
- * $Id: newtypecheck.ml,v 1.18 2002/07/18 13:43:23 tews Exp $
+ * $Id: newtypecheck.ml,v 1.19 2002/10/28 16:33:19 tews Exp $
  *
  *
  * the algorithm is homegrown and works in two passes
@@ -450,15 +450,18 @@ let rec unify tv_bindings t1 t2 =
        | Class _ ,_
        | Adt _ ,_
 							  (* we are in unify *)
-       | _, Groundtype _
-       | _, BoundTypeVariable _
-       | _, Self
-       | _, Carrier 
-       | _, Bool
-       | _, Function _
-       | _, Product _
-       | _, Class _
-       | _, Adt _           -> raise Unify
+(* double cases
+ * 	  | _, Groundtype _
+ * 	  | _, BoundTypeVariable _
+ * 	  | _, Self
+ * 	  | _, Carrier 
+ * 	  | _, Bool
+ * 	  | _, Function _
+ * 	  | _, Product _
+ * 	  | _, Class _
+ * 	  | _, Adt _ 
+ *)
+          -> raise Unify
     )
     
 and unify_arg tv_bindings arg1 arg2 = 
