@@ -18,11 +18,11 @@
  *
  * Created 1.10.97 by Hendrik
  *
- * Time-stamp: <Tuesday 16 July 02 10:09:03 tews@ithif51>
+ * Time-stamp: <Wednesday 18 September 02 12:39:02 tews@ithif51>
  *
  * Utility functions for ccsl parser
  *
- * $Id: parser.ml,v 1.26 2002/07/18 13:43:24 tews Exp $
+ * $Id: parser.ml,v 1.27 2002/09/18 15:35:04 tews Exp $
  *
  *)
 
@@ -408,7 +408,6 @@ let do_all_iface_start token =
       | MemberSymb _ 
       | InstClassSymb _
       | InstAdtSymb _
-      | MemberSymb _
 	-> assert(false)
     with Table.Not_defined -> ()
   in let scope = Symbol.start_block () in
@@ -770,8 +769,8 @@ let do_inherit token al (rename, endloc) =
 	   wrong_id_type token "class" ""
 					(* cant happen *)
     | InstClassSymb _
-    | InstAdtSymb _
-    | MemberSymb(_) -> assert(false)
+    | InstAdtSymb _ 
+      -> assert(false)
 
   in
   let _ = if not (check_parameters cl#get_parameters al) then
@@ -786,102 +785,115 @@ let do_inherit token al (rename, endloc) =
 
 
     (* test if this is a valid type for a class constructor *)
-let classconstructor_test dom codom =
-  (match codom with
-     | Self -> true
-     | _ -> false)
-  &
-  (count_self dom = 0)
+let classconstructor_test = function
+  | Self -> true
+  | Function(dom, Self) -> count_self dom = 0
+  | _ -> false
 
 
     (* test if this is a valid type for a proper attribute *)
-let attribute_test dom codom =
-  (match dom with
-     | Product( Self :: typlist ) ->
-	 (List.fold_left (fun n typ -> n + count_self typ) 0 typlist) = 0
-     | Self -> true
-     | _ -> false)
-  &
-  (count_self codom = 0)
+let attribute_test = function
+  | Function(dom, codom) ->
+      (match dom with
+	 | Product( Self :: typlist ) ->
+	     (List.fold_left (fun n typ -> n + count_self typ) 0 typlist) = 0
+	 | Self -> true
+	 | _ -> false)
+      &
+      (count_self codom = 0)
+  | _ -> false
 
 
     (* test if this is a valid type for a method *)
-let method_test dom codom =
-  (match dom with
-     | Product( Self :: typlist ) -> true
-     | Self -> true
-     | _ -> false)
+let method_test = function
+  | Function(dom,codom) ->
+      (match dom with
+	 | Product( Self :: typlist ) -> true
+	 | Self -> true
+	 | _ -> false)
+  | _ -> false
 
 
+(* DELETE
+ *     (* action for class constructors 
+ * 	* val do_var_class_constructor : token_type -> 
+ * 	*        pvs_type -> pvs_type -> unit 
+ * 	*)
+ * let do_var_class_constructor token dom codom =
+ *   let _ =
+ *     try 
+ * 	 let second = (ccl())#find_local_member token.token_name in
+ * 	 overloading_error (ciface()) token second
+ *     with Member_not_found -> () in
+ *   let _ = if not (classconstructor_test dom codom) then
+ *     begin
+ * 	 error_message (remove_option token.loc)
+ * 	   ("The Type " ^ 
+ * 	    (string_of_ccsl_type( Function(dom,codom) )) ^ 
+ * 	    " is not allowed for class constructors.");
+ * 	 raise Parsing.Parse_error
+ *     end in
+ *   let m : ccsl_member_type = 
+ *     new ccsl_pre_member_class (ciface()) token [] dom codom
+ * 	 NoVisibility Var_Constructor 
+ *   in
+ *     add_member_to_iface m
+ * 
+ *)
+
     (* action for class constructors 
-     * val do_var_class_constructor : token_type -> 
-     *        pvs_type -> pvs_type -> unit 
+     *
+     * val do_class_constructor : token_type -> ccsl_input_types -> unit 
      *)
-let do_var_class_constructor token dom codom =
-  let _ =
-    try 
-      let second = (ccl())#find_local_member token.token_name in
-      overloading_error (ciface()) token second
-    with Member_not_found -> () in
-  let _ = if not (classconstructor_test dom codom) then
-    begin
-      error_message (remove_option token.loc)
-	("The Type " ^ 
-	 (string_of_ccsl_type( Function(dom,codom) )) ^ 
-	 " is not allowed for class constructors.");
-      raise Parsing.Parse_error
-    end in
-  let m : ccsl_member_type = 
-    new ccsl_pre_member_class (ciface()) token [] dom codom
-      NoVisibility Var_Constructor 
-  in
-    add_member_to_iface m
-
-
-    (* action for class constructors 
-     * val do_const_class_constructor : token_type -> 
-     *        pvs_type -> unit 
-     *)
-let do_const_class_constructor token codom =
+let do_class_constructor token c_type =
 			      (* Sidecondition CONST_CONSTRUCTOR applies *)
-  let dom = Product [] in
   let _ =
     try 
       let second = (ccl())#find_local_member token.token_name in
       overloading_error (ciface()) token second
     with Member_not_found -> () in
-  let _ = if not (classconstructor_test dom codom) then
+  let _ = if not (classconstructor_test c_type) then
     begin
       error_message (remove_option token.loc)
 	("The Type " ^ 
-	 (string_of_ccsl_type( Function(dom,codom) )) ^ 
+	 (string_of_ccsl_type c_type) ^ 
 	 " is not allowed for constant class constructors.");
       raise Parsing.Parse_error
     end in
+  let (dom, codom, sort) = 
+    match c_type with
+      | Function(dom,codom) -> dom,codom,Var_Constructor
+      | codom -> ((Product []), codom, Const_Constructor)
+  in
   let m = new ccsl_pre_member_class (ciface()) token [] dom codom 
-	    NoVisibility Const_Constructor 
+	    NoVisibility sort
   in
     add_member_to_iface m
 
 
     (* action for proper class attributes 
-     * val do_attribute : token_type -> visibility -> 
-     *       pvs_type -> pvs_type -> unit
+     *
+     * val do_attribute : token_type -> ccsl_input_types -> unit 
      *)
-let do_attribute token dom codom =	
+let do_attribute token a_type =	
   let _ =
     try 
       let second = (ccl())#find_local_member token.token_name in
       overloading_error (ciface()) token second
     with Member_not_found -> () in
-  let _ = if not (attribute_test dom codom) then
+  let _ = if not (attribute_test a_type) then
     begin
       error_message (remove_option token.loc)
 	("The Type " ^ 
-	 (string_of_ccsl_type( Function(dom,codom) )) ^ 
+	 (string_of_ccsl_type a_type) ^ 
 	 " is not allowed for proper attributes.");
       raise Parsing.Parse_error
     end in
+  let dom,codom = (match a_type with
+		     | Function(dom, codom) -> dom, codom
+		     | _ -> assert false
+		  )
+  in
   let m = new ccsl_pre_member_class (ciface()) 
 	    token [] dom codom (cvis()) (Proper_Attribute None)
   in
@@ -890,22 +902,27 @@ let do_attribute token dom codom =
 
 
     (* action for methods and improper class attributes
-     * val do_method : token_type 
-     *                 -> pvs_type -> pvs_type -> unit 
+     *
+     * val do_method : token_type ->  ccsl_input_types -> unit 
+     *
      *)
-let do_method token dom codom =		
+let do_method token m_type =
   let _ =
     try 
       let second = (ccl())#find_local_member token.token_name in
       overloading_error (ciface()) token second
     with Member_not_found -> () in
-  let _ = if not (method_test dom codom) then
+  let _ = if not (method_test m_type) then
     begin error_message (remove_option token.loc)
 	("The Type " ^ 
-	 (string_of_ccsl_type( Function(dom,codom) )) ^ 
+	 (string_of_ccsl_type m_type) ^ 
 	 " is not allowed for methods.");
       raise Parsing.Parse_error
     end in
+  let dom,codom = (match m_type with
+		     | Function(dom,codom) -> dom,codom
+		     | _ -> assert false)
+  in
   let m = new ccsl_pre_member_class (ciface()) token [] dom codom (cvis()) 
 	    Normal_Method 
   in    
@@ -914,24 +931,27 @@ let do_method token dom codom =
 
     (* do a definitional extension 
      * 
-     * val do_definition : 
-     *   token_type -> ccsl_input_types -> ccsl_input_types -> 
-     * 	  ccsl_assertion -> unit
-     * 
+     * val do_definition : token_type -> ccsl_input_types -> 
+     *                                     ccsl_assertion -> unit
      *)
-let do_definition token dom codom equation =
+let do_definition token d_type equation =
   let _ =
     try 
       let second = (ccl())#find_local_member token.token_name in
       overloading_error (ciface()) token second
     with Member_not_found -> () in
-  let _ = if not (method_test dom codom) then
+  let _ = if not (method_test d_type) then
     begin error_message (remove_option token.loc)
 	("The Type " ^ 
-	 (string_of_ccsl_type( Function(dom,codom) )) ^ 
+	 (string_of_ccsl_type d_type) ^ 
 	 " is not allowed for methods.");
       raise Parsing.Parse_error
-    end in
+    end 
+  in let dom,codom = (match d_type with
+			| Function(dom,codom) -> dom,codom
+			| _ -> assert false
+		     )
+  in
   let m = new ccsl_pre_member_class (ciface()) token [] dom codom 
 	    NoVisibility Defined_Method
   in let def =
@@ -1151,52 +1171,54 @@ let adt_check_accessors token accessors dom =
       end
 
 
-    (* action for constant adt constructors
-     *
-     * takes name accessorlist type
-     * because it is a constructor with no arguments, accessorlist 
-     * should contain at most one id and type should be Carrier
-     *
-     * val do_const_adt_constructor : token_type -> token_type list -> 
-     * 		pvs_type -> unit
-     *)
-let do_const_adt_constructor token accessors codom =
-  let dom = Product [] in
-       (* no overloading any more *)
-  let _ = 
-    try 
-      let second = (cadt())#find_local_member token.token_name in
-      overloading_error (ciface()) token second
-    with Member_not_found -> () in
-  let _ = if accessors <> [] then 
-    begin 
-      error_message (remove_option token.loc)
-	("Constant constructors cannot have accessors.");
-      raise Parsing.Parse_error
-    end in
-  let _ = match codom with
-    | Carrier -> ()
-    | _ -> begin error_message (remove_option token.loc)
-	  ("An ADT constructor must have a " ^ 
-	   "codomain type of Carrier.");
-	         raise Parsing.Parse_error
-      end in
-  let m = new ccsl_pre_member_class (ciface()) token [] dom codom NoVisibility
-    Adt_Const_Constructor
-  in
-  let rec_token = {token_name = (Names.constructor_recognizer m);
-		   loc = None;
-		  }
-  in
-  let recognizer = new ccsl_pre_member_class (ciface())
-		     rec_token []
-		     (Product[]) (Function(Carrier,Bool))
-		     NoVisibility Adt_Recognizer
-  in
-    m#register_recognizer recognizer;
-    add_member_to_iface m;
-    add_member_to_iface recognizer
-  
+(* DELETE
+ *     (* action for constant adt constructors
+ * 	*
+ * 	* takes name accessorlist type
+ * 	* because it is a constructor with no arguments, accessorlist 
+ * 	* should contain at most one id and type should be Carrier
+ * 	*
+ * 	* val do_const_adt_constructor : token_type -> token_type list -> 
+ * 	* 		pvs_type -> unit
+ * 	*)
+ * let do_const_adt_constructor token accessors codom =
+ *   let dom = Product [] in
+ * 	  (* no overloading any more *)
+ *   let _ = 
+ *     try 
+ * 	 let second = (cadt())#find_local_member token.token_name in
+ * 	 overloading_error (ciface()) token second
+ *     with Member_not_found -> () in
+ *   let _ = if accessors <> [] then 
+ *     begin 
+ * 	 error_message (remove_option token.loc)
+ * 	   ("Constant constructors cannot have accessors.");
+ * 	 raise Parsing.Parse_error
+ *     end in
+ *   let _ = match codom with
+ *     | Carrier -> ()
+ *     | _ -> begin error_message (remove_option token.loc)
+ * 	     ("An ADT constructor must have a " ^ 
+ * 	      "codomain type of Carrier.");
+ * 		    raise Parsing.Parse_error
+ * 	 end in
+ *   let m = new ccsl_pre_member_class (ciface()) token [] dom codom NoVisibility
+ *     Adt_Const_Constructor
+ *   in
+ *   let rec_token = {token_name = (Names.constructor_recognizer m);
+ * 		      loc = None;
+ * 		     }
+ *   in
+ *   let recognizer = new ccsl_pre_member_class (ciface())
+ * 			rec_token []
+ * 			(Product[]) (Function(Carrier,Bool))
+ * 			NoVisibility Adt_Recognizer
+ *   in
+ *     m#register_recognizer recognizer;
+ *     add_member_to_iface m;
+ *     add_member_to_iface recognizer
+ *   
+ *)
 
     (* generate accessor names c_acc1 ... c_acc5 *)
 let generate_accessor_names c_token number = 
@@ -1217,41 +1239,60 @@ let generate_accessor_names c_token number =
      * takes name accessorlist domain codomain
      * because it is a constructor, codomain should be Carrier
      *
-     * val do_var_adt_constructor : token_type -> token_type list -> 
-     *   pvs_type -> pvs_type -> unit
+     * val do_adt_constructor : token_type -> token_type list -> 
+     *    ccsl_input_types -> unit
      *)
-let do_var_adt_constructor token accessors dom codom =
+let do_adt_constructor token accessors c_type =
   let _ =
     try 
       let second = (cadt())#find_local_member token.token_name in
       overloading_error (ciface()) token second
-    with Member_not_found -> () in
+    with Member_not_found -> () 
+  in
+  let (dom, codom, is_const) = 
+    match c_type with
+      | Function(dom,Carrier) -> dom, Carrier, false
+      | Carrier -> ((Product []), Carrier, true)
+      | _ ->
+	  begin 
+	    error_message (remove_option token.loc)
+	      ("An ADT constructor must have a " ^ 
+	       "codomain type of Carrier.");
+	    raise Parsing.Parse_error
+	  end 
+  in
+  let _ = (if is_const && accessors <> [] then 
+	     begin 
+	       error_message (remove_option token.loc)
+		 ("Constant constructors cannot have accessors.");
+	       raise Parsing.Parse_error
+	     end
+	  )
+  in
   let _ = unique_accessors accessors in
 (* Hendrik check for adt wide unique accessors, recognizers *)
 				(* check arity of domain and accessors *)
-  let _ = if accessors <> [] then 
+  let _ = if not is_const && accessors <> [] then 
     adt_check_accessors token accessors dom in
-					(* check docomain *)
-  let _ = match codom with
-    | Carrier -> ()
-    | _ -> begin error_message (remove_option token.loc)
-	  ("An ADT constructor must have a " ^ 
-	   "codomain type of Carrier.");
-	         raise Parsing.Parse_error
-      end in
 		(* accessors are optional, generate something if necessary *)
   let accessor_names = 
-    if accessors <> [] then 
-      accessors
+    if is_const 
+    then []
+    else if accessors <> [] 
+    then accessors
     else 
       let arity = match dom with 
     	| Product l -> List.length l
     	| _ -> 1
       in generate_accessor_names token arity
+  in 
+  let sort = 
+    if is_const then Adt_Const_Constructor
+    else Adt_Var_Constructor
+  in
 			(* for constructors the visibility flag is ignored *)
-  in let m = new ccsl_pre_member_class (ciface()) token [] 
-	       dom codom NoVisibility
-	       Adt_Var_Constructor  
+  let m = new ccsl_pre_member_class (ciface()) token [] 
+	       dom codom NoVisibility sort 
   in let domtyplist = match dom with
     | Product tl -> tl
     | t -> [t]
@@ -1274,7 +1315,8 @@ let do_var_adt_constructor token accessors dom codom =
 		     (Product[]) (Function(Carrier,Bool))
 		     NoVisibility Adt_Recognizer
   in
-    m#register_accessors accessor_mems;
+    if not is_const then
+      m#register_accessors accessor_mems;
     m#register_recognizer recognizer;
     add_member_to_iface m;
     add_member_to_iface recognizer;
@@ -1376,12 +1418,11 @@ let carrier_action loc =
 let do_type_product tl loc =
   begin
     if List.length tl < 2 then 
-      let emergency_token = emergency_token() in 
-	begin
-    	  error_message loc
-	    ( "Typeconstructor Product needs at least two arguments.");
-    	  raise Parsing.Parse_error
-	end 
+      begin
+    	error_message loc
+	  ( "Typeconstructor Product needs at least two arguments.");
+    	raise Parsing.Parse_error
+      end 
     else 
       Product tl
   end
@@ -1452,7 +1493,7 @@ let do_instclass token arglist =
 					(* cant happen *)
     | InstClassSymb _
     | InstAdtSymb _
-    | MemberSymb(_) -> assert(false)
+      -> assert(false)
 
   in if (check_parameters cl#get_parameters arglist) then
       Class(cl, arglist)
