@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Tuesday 25 June 02 14:55:52 tews@ithif51>
+ * Time-stamp: <Tuesday 16 July 02 21:12:15 tews@ithif56.inf.tu-dresden.de>
  *
  * Resolution pass for CCSL
  *
- * $Id: resolution.ml,v 1.15 2002/07/03 12:01:16 tews Exp $
+ * $Id: resolution.ml,v 1.16 2002/07/18 13:43:24 tews Exp $
  *
  *)
 
@@ -155,12 +155,23 @@ let rec do_basic_expr ccl loc = function
 		  if m#is_inherited 
 		  then remove_option(m#hosting_class#get_heir)
 		  else m#hosting_class 
-		in let mfulltype =
-			(* make type variables unique, before exporting
-			 * this is only neccessary for (co)reduce, 
+		in let pre_mfulltype =
+			(* make type variables unique and unsmart, 
+			 * before exporting.
+			 * This is only neccessary for class specials
 			 * but does not harm in general
 			 *)
-		    uniquify_type_variables m#get_full_type
+		    unsmart_type (uniquify_type_variables m#get_full_type)
+
+		in let mfulltype =
+		    (* mimic Isabelle curried Constructors *)
+		    if !output_mode = Isa_mode & 
+		      m#get_sort = Adt_Var_Constructor
+		    then
+		      curry_constructor_type pre_mfulltype
+		    else
+		      pre_mfulltype
+
 		in let instiface, memtyp = 
 		    if ccl#get_name = topiface#get_name 
                     then
@@ -210,12 +221,13 @@ let rec do_basic_expr ccl loc = function
 		   typeparams args
 	      ) in
       let _, memtype =
-			(* make type variables unique, before exporting
-			 * this is only neccessary for (co)reduce, 
+			(* make type variables unique and unsmart, 
+			 * before exporting.
+			 * This is only neccessary for class specials
 			 * but does not harm in general
 			 *)
-	  export_member_with_args iface m args 
-	    (uniquify_type_variables m#get_full_type)
+	export_member_with_args iface m args
+	  (unsmart_type (uniquify_type_variables m#get_full_type))
       in let _ = dr ("quali member " ^ 
 		    m#get_name ^ " : " ^
 		    (string_of_ccsl_type memtype)
@@ -306,13 +318,13 @@ and do_expression ccl loc expr =
 	  TypedTerm(recurse_exp ex, typ)
 
 	  (* method selection are resolved during type checking *)
-      | MethodSelection(ex, typeopt, m) ->
+      | MethodSelection(ex, instiface, m) ->
 	  dr ("MethodSelection " ^ 
 	      (match m with
 		 | Unresolved name -> name.token_name
 		 | Resolved mem -> mem#get_name
 	      ));
-	  MethodSelection(recurse_exp ex, typeopt, m)
+	  MethodSelection(recurse_exp ex, instiface, m)
       | Tuple(ex_list) -> 
 	  dr "Tuple";
 	  Tuple(List.map recurse_exp ex_list)
@@ -502,8 +514,6 @@ and do_expression ccl loc expr =
       | Map _
       | SmartAbstraction _
       | SmartApplication _
-      | Comment_str _
-      | Comment_expr _
       | Comprehension _ ->
 	  assert(false)
 	
