@@ -18,11 +18,11 @@
  *
  * Created 3.11.99 by Hendrik
  *
- * Time-stamp: <Wednesday 5 June 02 22:46:44 tews@ithif56.inf.tu-dresden.de>
+ * Time-stamp: <Thursday 4 July 02 18:29:39 tews@ithif51>
  *
  * Semantics
  *
- * $Id: semantics_theory.ml,v 1.15 2002/07/03 12:01:16 tews Exp $
+ * $Id: semantics_theory.ml,v 1.16 2002/07/18 13:43:24 tews Exp $
  *
  *)
 
@@ -443,7 +443,9 @@ class ['class_type, 'member_type] ccsl_pre_semantics_theory
       @
       [self#do_model] 
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 end
 
 class ccsl_semantics_theory cl = 
@@ -518,7 +520,8 @@ class ['class_type, 'member_type] ccsl_pre_basic_theory
 	(fun ianc ->				(* iteration function *)
 	   Proved(			(* Pack lemma together with proof *)
 	     lemma ianc,
-	     Anon_proof proof))
+	     PvsProof(
+	       Anon_proof proof)))
 	cl#get_resolved_ancestors		(* get all direct ancestors *)
 
 
@@ -655,7 +658,7 @@ class ['class_type, 'member_type] ccsl_pre_basic_theory
 	  Lemma(
 	    name_of_assertion_lemma ass.assertion_name.token_name,
 	    form),
-	  Anon_proof proof)
+	  PvsProof(Anon_proof proof))
 
     method private do_assertion_lemmas = 
       let ass_count = ref 1 in
@@ -755,7 +758,7 @@ class ['class_type, 'member_type] ccsl_pre_basic_theory
 	  Lemma(
 	    name_of_assertion_lemma crea.assertion_name.token_name,
 	    form),
-	  Anon_proof proof)
+	  PvsProof(Anon_proof proof))
 
 
     method private do_creation_lemmas =
@@ -783,7 +786,9 @@ class ['class_type, 'member_type] ccsl_pre_basic_theory
       @
       self#do_creation_lemmas
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 end
 
 class ccsl_basic_theory cl = 
