@@ -18,11 +18,11 @@
  *
  * Created 17.6.99 by Hendrik
  *
- * Time-stamp: <Friday 5 July 02 18:40:37 tews@ithif51>
+ * Time-stamp: <Monday 28 October 02 14:48:41 tews@ithif51>
  *
  * the theories for ground signatures
  *
- * $Id: sig_theory.ml,v 1.4 2002/07/18 13:43:24 tews Exp $
+ * $Id: sig_theory.ml,v 1.6 2002/10/28 16:33:19 tews Exp $
  *
  *)
 
@@ -98,6 +98,7 @@ class ccsl_isar_start_sig si =
       IsabelleStartFile
       (ccsl_sig_file_name si)
       imports
+      true				(* do proofs *)
 
 
 class ccsl_isar_close_sig si =
@@ -108,6 +109,7 @@ class ccsl_isar_close_sig si =
     IsabelleCloseFile
     (ccsl_sig_file_name si)
     []
+    true				(* do proofs *)
 
     
 
@@ -248,9 +250,9 @@ class ccsl_sig_def_theory si thname items =
 
 
 let ccsl_sig_def_theories si =
-(* *)					(* debugging support *)
+(* 					(* debugging support *)
   let signame = si#get_name in
-(* *)
+*)
   let items = 
     (List.map (fun def -> DefExt def) si#get_definitions) @ 
     (List.map (fun td -> TypeDef td)
