@@ -18,17 +18,23 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Tuesday 14 May 02 17:29:32 tews@ithif51>
+ * Time-stamp: <Friday 5 July 02 18:30:36 tews@ithif51>
  *
  * theories for ground signatures
  *
- * $Id: sig_theory.mli,v 1.3 2002/05/22 13:42:43 tews Exp $
+ * $Id: sig_theory.mli,v 1.4 2002/07/18 13:43:24 tews Exp $
  *
  *)
 
 
 open Classtypes
 
+class ccsl_isar_start_sig
+  : ccsl_iface_type -> ccsl_sig_theory_type
+
+class ccsl_isar_close_sig
+  : ccsl_iface_type -> ccsl_sig_theory_type
+
 val ccsl_sig_def_theories
   : ccsl_iface_type -> ccsl_sig_theory_type list
 
