@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Tuesday 16 July 02 10:15:44 tews@ithif51>
+ * Time-stamp: <Wednesday 24 July 02 16:30:23 tews@ithif51>
  *
  * generic classes for all ccsl class and adt theories
  *
- * $Id: theory_class.ml,v 1.15 2002/07/18 13:43:25 tews Exp $
+ * $Id: theory_class.ml,v 1.16 2002/09/18 15:35:04 tews Exp $
  *
  *)
 
@@ -555,6 +555,7 @@ class ['class_type, 'member_type]
   delimiter 
   (file_name : string)
   (isar_imports : string list)
+  (do_proofs : bool)
   : ['class_type, 'member_type] ccsl_pre_sig_theory_type
   =
   object (self : 'self)
@@ -578,6 +579,9 @@ class ['class_type, 'member_type]
 
     method get_isar_imports = isar_imports
 
+      (* Override this method, if proofs should not be written *)
+    method do_proofs = do_proofs
+
 end (* ccsl_isabelle_delimiter_theory_class *)
 
   
