@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Tuesday 16 July 02 10:45:04 tews@ithif51>
+ * Time-stamp: <Monday 28 October 02 16:36:05 tews@ithif51>
  *
  * Utility functions for ccsl input types
  *
- * $Id: types_util.ml,v 1.24 2002/07/18 13:43:25 tews Exp $
+ * $Id: types_util.ml,v 1.26 2002/10/28 16:33:19 tews Exp $
  *
  *)
 
@@ -142,6 +142,46 @@ and check_for_params_args param_p args =
     ) args
 
 
+    (****************************
+     * class_ingredient checks if type contains some class
+     * if so -> true
+     * if not -> false
+     *
+     * val class_ingredient : 
+     * 	   ('cl,'mem) top_pre_types -> bool
+     * 
+     *)
+let rec class_ingredient = function
+  | Groundtype (_, args) 	-> class_ingredient_args args
+  | BoundTypeVariable id 	-> false
+  | Self			-> false
+  | Carrier 			-> false
+  | Bool 			-> false
+  | Function( dom, codom) 	-> (class_ingredient dom 
+ 				    || class_ingredient codom)
+  | Product( types ) 		-> 
+      List.exists (fun typ -> class_ingredient typ) types
+  | Class(cl, args )		-> true
+  | Adt(cl, flag, args )	-> class_ingredient_args args
+		(* do records as an exception *)
+  | Record label_list 		->
+      List.exists (fun (_,typ) -> class_ingredient typ) label_list
+					(* not in ccsl input types *)
+  | TypeConstant _
+  | FreeTypeVariable _
+  | IFace _
+  | Array _
+  | Predtype _
+  | SmartFunction _ -> assert(false)
+
+
+and class_ingredient_args args = 
+  List.exists
+    (fun arg -> match arg with 
+       | TypeArgument(typ) -> class_ingredient typ
+    ) args
+
+
     (****************
      * checks if type corresponds to a constant functor, 
      * in which certain parameters (given by param_p) do not occur
@@ -440,6 +480,10 @@ let rec iter_components variance action typ = match typ with
 
 
 and iter_component_arglist variance action arguments parameters = 
+(*					(* debugging support *)
+  let xxx = sqrt 2.0 in
+					(* debugging support *)
+*)
   List.iter2 (function TypeArgument(typ) -> 
 		(function TypeParameter id ->
 		   iter_components (variance_subst variance 
@@ -464,6 +508,10 @@ let iter_components_add_component iface typ =
   iter_components Pos (do_add_component iface) typ
 
 let iter_component_arglist_add_component iface arguments parameters =
+(*					(* debugging support *)
+  let ifname = iface#get_name in
+					(* debugging support *)
+*)
   iter_component_arglist Pos (do_add_component iface) arguments parameters
 
 
@@ -563,21 +611,24 @@ let rec eq_ccsl_types t1 t2 = t1 == t2 or match t1,t2 with
   | Record _ ,_
   | IFace _ ,_
 
-  | _, Groundtype _
-  | _, TypeConstant _
-  | _, BoundTypeVariable _
-  | _, FreeTypeVariable _
-  | _, Self
-  | _, Carrier 
-  | _, Bool
-  | _, Function _
-  | _, SmartFunction _
-  | _, Product _
-  | _, Class _
-  | _, Adt _
-  | _, Predtype _
-  | _, Record _
-  | _, IFace _ -> false
+(* double cases
+ *   | _, Groundtype _
+ *   | _, TypeConstant _
+ *   | _, BoundTypeVariable _
+ *   | _, FreeTypeVariable _
+ *   | _, Self
+ *   | _, Carrier 
+ *   | _, Bool
+ *   | _, Function _
+ *   | _, SmartFunction _
+ *   | _, Product _
+ *   | _, Class _
+ *   | _, Adt _
+ *   | _, Predtype _
+ *   | _, Record _
+ *   | _, IFace _ 
+ *)
+      -> false
 
 and eq_ccsl_typ_option o1 o2 = o1 == o2 or eq_option eq_ccsl_types o1 o2
 
@@ -673,24 +724,26 @@ and eq_ccsl_formulas f1 f2 = f1 == f2 or match (f1,f2) with
   | Bisim _, _
   | Obseq _, _
 
-  | _, True
-  | _, False
-  | _, Not _
-  | _, And _
-  | _, Or _
-  | _, Implies _
-  | _, Iff _
-  | _, Equal _
-(*   | _, LessOrEqual _
+(* double cases
+ *   | _, True
+ *   | _, False
+ *   | _, Not _
+ *   | _, And _
+ *   | _, Or _
+ *   | _, Implies _
+ *   | _, Iff _
+ *   | _, Equal _
+ * (*   | _, LessOrEqual _
+ *  *)
+ *   | _, Forall _
+ *   | _, Exists _
+ *   | _, ConstantPredicate _
+ *   | _, Formula _
+ *   | _, MetaImplies _
+ *   | _, MetaForall _ 
+ *   | _, Bisim _
+ *   | _, Obseq _
  *)
-  | _, Forall _
-  | _, Exists _
-  | _, ConstantPredicate _
-  | _, Formula _
-  | _, MetaImplies _
-  | _, MetaForall _ 
-  | _, Bisim _
-  | _, Obseq _
       -> false
 
 and eq_ccsl_basic_expressions be1 be2 = be1 == be2 or match be1,be2 with 
@@ -714,8 +767,11 @@ and eq_ccsl_basic_expressions be1 be2 = be1 == be2 or match be1,be2 with
 	(* cases where constructors do not match *)
   | Member _,_
   | TermVar _,_
-  | _, Member _
-  | _, Member _
+
+(* double cases
+ *   | _, Member _
+ *   | _, TermVar _
+ *)
       -> false
 
 
