@@ -18,11 +18,11 @@
  *
  * Created 15.1.99 by Hendrik
  *
- * Time-stamp: <Monday 24 June 02 17:44:21 tews@ithif51>
+ * Time-stamp: <Tuesday 13 August 02 11:16:48 tews@ithif51>
  *
  * global control variables of the loop compiler
  *
- * $Id: global.mli,v 1.12 2002/07/03 12:01:17 tews Exp $
+ * $Id: global.mli,v 1.13 2002/09/18 15:35:05 tews Exp $
  *
  *)
 
@@ -57,7 +57,7 @@ val output_mode : output_mode ref
     (* if true parse the prelude(s)
      * set in main.ml, via -no-prelude option
      *)
-(* val parse_prelude : bool ref *)
+val parse_prelude : bool ref
 
 
     (* exceptions for -pedantic errors *)
