@@ -18,11 +18,11 @@
  *
  * Created 11.11.99 by Hendrik
  *
- * Time-stamp: <Tuesday 16 July 02 21:28:04 tews@ithif56.inf.tu-dresden.de>
+ * Time-stamp: <Monday 28 October 02 14:47:22 tews@ithif51>
  *
  * substitution and optimization for top_types
  *
- * $Id: logic_util.ml,v 1.22 2002/07/18 13:43:27 tews Exp $
+ * $Id: logic_util.ml,v 1.24 2002/10/28 16:33:20 tews Exp $
  *
  *)
 
@@ -478,13 +478,13 @@ and substitute_expression ((_,eq_ex) as eqs) ((_,ex_sub) as subst) expr =
 	       let n_pred = recurse_exp pred in
 		 if n_typ == typ && n_pred == pred then
 		   expr
-		 else Box(typ,n_pred,tlist)
+		 else Box(n_typ,n_pred,tlist)
 	   | Diamond(typ,pred,tlist) ->
 	       let n_typ =  recurse_type typ in
 	       let n_pred = recurse_exp pred in
 		 if n_typ == typ && n_pred == pred then
 		   expr
-		 else Diamond(typ,n_pred,tlist)
+		 else Diamond(n_typ,n_pred,tlist)
 					  (* we are in substitute_expression *)
 	   | Every(typ, form_list) -> 
 	       let ntyp = recurse_type typ in
@@ -1223,7 +1223,12 @@ let vadd i1 i2 = match i1,i2 with
   | _,_ -> i1 + i2
 
 
-let rec variance_subst v1 v2 = match v1,v2 with
+let rec variance_subst v1 v2 = 
+(*					(* debugging support *)
+  let xxx = sqrt 2.0 in
+					(* debugging support *)
+*)
+    match v1,v2 with
   | Pair(n1,p1), Pair(n2,p2) -> Pair( max (vadd n1 p2) (vadd p1 n2),
 				      max (vadd n1 n2) (vadd p1 p2))
   | Pair _ ,_ -> variance_subst (make_simple v1) v2
