@@ -4,7 +4,7 @@ files="Common/config.ml Doc/ccslc.1 Doc/ccslc.html"
 
 prefix=/usr/local
 exec_prefix=${prefix}
-libdir=${exec_prefix}/lib/ccsl/pvs
+libdir=/home/tews/Privat/tmp/Ccslc/Lib/Pvs
 
 
 echo writing files $files
